"use strict";
/**
 * GitDocumentDB plugin for remote connection using NodeGit
 * Copyright (c) Hidekazu Kubota
 *
 * This source code is licensed under the Mozilla Public License Version 2.0
 * found in the LICENSE file in the root directory of this source tree.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Err = void 0;
/**
 * Namespace for errors
 *
 * @public
 */
var Err;
(function (Err) {
    /**
     * BaseError
     *
     * @privateRemarks
     * Use 'unknown' type assertion for constructor arguments in subclass of BaseError
     * to use 'expect' in test. See https://github.com/facebook/jest/issues/8279
     */
    class BaseError extends Error {
        constructor(e) {
            super(e);
            this.name = new.target.name;
            Object.setPrototypeOf(this, new.target.prototype);
        }
    }
    /**
     * @public
     */
    class CannotConnectError extends BaseError {
        constructor(retry, url, mes) {
            super(`Cannot connect to ${url}: ${mes}`);
            this.retry = retry;
        }
    }
    Err.CannotConnectError = CannotConnectError;
    /**
     * @public
     */
    class CannotCloneRepositoryError extends BaseError {
        constructor(url) {
            super(`Cannot clone repository: ${url}`);
        }
    }
    Err.CannotCloneRepositoryError = CannotCloneRepositoryError;
    /**
     * @public
     */
    class InvalidRepositoryURLError extends BaseError {
        constructor(url) {
            super(`Repository URL is invalid: ${url}`);
        }
    }
    Err.InvalidRepositoryURLError = InvalidRepositoryURLError;
    /**
     * @remark
     * Add prefix 'Remote' due to UndefinedPersonalAccessTokenError exists
     * in GitDocumentDB,
     *
     * @public
     */
    class RemoteUndefinedPersonalAccessTokenError extends BaseError {
        constructor() {
            super(`Personal Access Token of your GitHub account is needed.`);
        }
    }
    Err.RemoteUndefinedPersonalAccessTokenError = RemoteUndefinedPersonalAccessTokenError;
    /**
     * @public
     */
    class InvalidSSHKeyPathError extends BaseError {
        constructor() {
            const e = `Invalid SSH key path`;
            super(e);
        }
    }
    Err.InvalidSSHKeyPathError = InvalidSSHKeyPathError;
    /**
     * @public
     */
    class HttpProtocolRequiredError extends BaseError {
        constructor(url) {
            super(`HTTP protocol is required: ${url}`);
        }
    }
    Err.HttpProtocolRequiredError = HttpProtocolRequiredError;
    /**
     * @public
     */
    class RequestTimeoutError extends BaseError {
        constructor(url) {
            super(`Request timeout: ${url}`);
        }
    }
    Err.RequestTimeoutError = RequestTimeoutError;
    /**
     * @public
     */
    class SocketTimeoutError extends BaseError {
        constructor(url) {
            super(`Socket timeout: ${url}`);
        }
    }
    Err.SocketTimeoutError = SocketTimeoutError;
    /**
     * @public
     */
    class HTTPNetworkError extends BaseError {
        constructor(mes) {
            super(`HTTPNetworkError: ${mes}`);
        }
    }
    Err.HTTPNetworkError = HTTPNetworkError;
    /**
     * @public
     */
    class InvalidURLError extends BaseError {
        constructor(url) {
            super(`Invalid url: ${url}'`);
        }
    }
    Err.InvalidURLError = InvalidURLError;
    /**
      * @public
      */
    class RemoteRepositoryNotFoundError extends BaseError {
        constructor(url) {
            super(`Repository does not exist, or you do not have permission to access the repository: ${url}`);
        }
    }
    Err.RemoteRepositoryNotFoundError = RemoteRepositoryNotFoundError;
    /**
     * @public
     */
    class PushPermissionDeniedError extends BaseError {
        constructor(mes) {
            super(`Permission denied to push to the repository: ${mes}`);
        }
    }
    Err.PushPermissionDeniedError = PushPermissionDeniedError;
    /**
     * @public
     */
    class FetchPermissionDeniedError extends BaseError {
        constructor(mes) {
            super(`Permission denied to fetch to the repository: ${mes}`);
        }
    }
    Err.FetchPermissionDeniedError = FetchPermissionDeniedError;
    /**
     * @public
     */
    class FetchConnectionFailedError extends BaseError {
        constructor(mes) {
            super(`Fetch connection failed: ${mes}`);
        }
    }
    Err.FetchConnectionFailedError = FetchConnectionFailedError;
    /**
     * @public
     */
    class PushConnectionFailedError extends BaseError {
        constructor(mes) {
            super(`Push connection failed: ${mes}`);
        }
    }
    Err.PushConnectionFailedError = PushConnectionFailedError;
    /**
     * @public
     */
    class UnfetchedCommitExistsError extends BaseError {
        constructor() {
            super('Cannot push because a reference that you are trying to update on the remote contains commits that are not present locally.');
        }
    }
    Err.UnfetchedCommitExistsError = UnfetchedCommitExistsError;
    /**
     * @public
     */
    class GitPushError extends BaseError {
        constructor(mes) {
            super(`Push error in Git : ${mes}`);
        }
    }
    Err.GitPushError = GitPushError;
    /**
    * @public
    */
    class GitFetchError extends BaseError {
        constructor(mes) {
            super(`Fetch error in sync worker: ${mes}`);
        }
    }
    Err.GitFetchError = GitFetchError;
    /**
     * @public
     */
    class NoMergeBaseFoundError extends BaseError {
        constructor() {
            super(`No merge base found`);
        }
    }
    Err.NoMergeBaseFoundError = NoMergeBaseFoundError;
})(Err = exports.Err || (exports.Err = {}));
//# sourceMappingURL=error.js.map